Installation — django-critic v0.2.1 documentation

django-critic v0.2.1 documentation

# Installation

- Table of Contents
- index
  next
  previous

# Installation

## Getting django-critic

You can get django-crtic in a couple ways:

1. Clone the git repository from here

2. Download the latest build here

3. Use PIP to install from our opensource site pypi
     - pip install django-critic

## Installing

Add critic do your INSTALLED_APPS setting.

    INSTALLED_APPS = (
            ...
            'critic',
            ...
    )

Sync the database:

    $ ./manage.py syncdb

Add the urls

    urlpatterns += patterns('',
            ...
            (r'^critic/', include('critic.urls')),
            ...
    )